==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer/src/com/sslexplorer/properties/actions/AbstractPropertiesAction.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.properties.actions;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.sslexplorer.boot.AbstractPropertyKey;
import com.sslexplorer.boot.PropertyClass;
import com.sslexplorer.boot.PropertyDefinition;
import com.sslexplorer.boot.PropertyDefinitionCategory;
import com.sslexplorer.boot.PropertyList;
import com.sslexplorer.boot.Util;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.actions.AuthenticatedDispatchAction;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.PropertyItem;
import com.sslexplorer.properties.forms.AbstractPropertiesForm;
import com.sslexplorer.properties.forms.PropertiesForm;
import com.sslexplorer.security.LogonControllerFactory;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.security.User;

public abstract class AbstractPropertiesAction extends AuthenticatedDispatchAction {
    static Log log = LogFactory.getLog(AbstractPropertiesAction.class);

    public AbstractPropertiesAction() {
        super();
    }

    public ActionForward reset(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.clearValues();
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        rebuildItems(f.getParentCategory(), f, request, user);
        return mapping.findForward("display");
    }

    public ActionForward unspecified(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                     HttpServletResponse response) throws Exception {
        // Initialise form
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        pf.clearValues();
        pf.setUpdateAction(mapping.getPath() + ".do");
        pf.setInput(mapping.getInput());

        // Now try the struts supplied action mapping parameter
        if (mapping.getParameter() != null && !mapping.getParameter().equals("")) {
            PropertyList pl = new PropertyList(mapping.getParameter());
            Properties pr = pl.getAsNameValuePairs();
            BeanUtils.populate(pf, pr);
        }

        if ("changeSelectedCategory".equalsIgnoreCase(pf.getActionTarget())) {
            pf.setSelectedCategory(pf.getNewSelectedCategory());
        }

        // Build and display
        rebuildItems(pf.getParentCategory(), pf, request, getSessionInfo(request).getUser());
        return mapping.findForward("display");
    }

    public ActionForward changeSelectedCategory(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                                HttpServletResponse response) throws Exception {
        if (log.isDebugEnabled())
            log.debug("Storing properties");
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.storeItems();
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        f.setSelectedCategory(f.getNewSelectedCategory());
        f.setNewSelectedCategory(-1);
        rebuildItems(f.getParentCategory(), f, request, user);
        return mapping.findForward("display");
    }

    public ActionForward cancel(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        pf.setSelectedCategory(-1);
        pf.clearValues();
        int newCategory = pf.popCategory();
        pf.setParentCategory(newCategory);
        rebuildItems(newCategory, pf, request, user);
        return mapping.findForward("display");
    }

    public ActionForward displayCategory(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                         HttpServletResponse response) throws Exception {
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        pf.setSelectedCategory(-1);
        pf.pushCategory(pf.getParentCategory());
        pf.setParentCategory(pf.getNewSelectedCategory());
        pf.setNewSelectedCategory(-1);
        rebuildItems(pf.getParentCategory(), pf, request, user);
        return mapping.findForward("display");
    }

    public ActionForward commit(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
    	SessionInfo sessionInfo = getSessionInfo(request);
    	
        // Temporarily store the properties
        if (log.isDebugEnabled())
            log.debug("Commiting properties");
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.storeItems();

        // Check for save abilitiy
        if (!((PropertiesForm) form).getEnabled()) {
            throw new Exception("Disabled.");
        }

        // Set the properties
        for (Iterator i = f.storedItems(); i.hasNext();) {
            PropertyItem item = (PropertyItem) i.next();
            PropertyDefinition def = item.getDefinition();
            String val = null;
            val = String.valueOf(item.getPropertyValue());
            if (log.isDebugEnabled())
                log.debug("Setting '" + def.getName() + "' to '" + val + "'");
            Property.setProperty(createKey(item.getDefinition(), f, sessionInfo), val, sessionInfo);
        }
        CoreUtil.resetMainNavigation(request.getSession());

        // Messages
        ActionMessages messages = new ActionMessages();
        messages.add(Globals.MESSAGES_KEY, new ActionMessage("message.propertiesSaved"));
        saveMessages(request, messages);

        // Clean up and forward
        f.clearValues();
        if (f.getForwardTo() != null && !f.getForwardTo().equals("")) {
            return new ActionForward(f.getForwardTo(), f.isRedirect());
        } else {
            return cancel(mapping, form, request, response);
        }
    }

    protected String getMethodName(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                   HttpServletResponse response, String parameter) throws Exception {
        return request.getParameter("actionTarget");
    }

    protected void rebuildItems(int parentCategory, AbstractPropertiesForm pf, HttpServletRequest request, User user)
                    throws Exception {
    	SessionInfo sessionInfo = getSessionInfo(request);
        List<PropertyDefinitionCategory> categoryDefinitions = new ArrayList<PropertyDefinitionCategory>();
        List<PropertyDefinitionCategory> subCategories = new ArrayList<PropertyDefinitionCategory>();
        Collection<PropertyDefinitionCategory> sourceCategories = null;
        List<PropertyItem> propertyItems = new ArrayList<PropertyItem>();
        for (PropertyClass propertyClass : pf.getPropertyClasses()) {

            /*
             * If no parent category is supplied, then assume all categories in
             * the class, otherwise get all the child categories of the supplied
             * one
             */
            if (parentCategory == 0) {
                sourceCategories = propertyClass.getCategories();
            } else {
                PropertyDefinitionCategory category = propertyClass.getPropertyDefinitionCategory(parentCategory);
                if (category != null) {
                    sourceCategories = category.getCategories();
                }
                else {
                    sourceCategories = null;
                }
            }

            if (sourceCategories != null) {
                for (PropertyDefinitionCategory def : sourceCategories) {
                    if(def.isEnabled()) {
                        if (def.size() > 0) {
                        	if(!subCategories.contains(def))
                        		subCategories.add(def);
                        } else {
                        	if(!categoryDefinitions.contains(def))
                        		categoryDefinitions.add(def);
                            if (pf.getSelectedCategory() == -1) {
                                pf.setSelectedCategory(def.getId());
                            }
                        }
                    }
                }
            }

            for (PropertyDefinition def : propertyClass.getDefinitions()) {
                if (!def.isHidden() && def.getCategory() == pf.getSelectedCategory()) {
                    propertyItems.add(pf.retrieveItem(def.getName(), new PropertyItem(this, request, def, Property
                                    .getProperty(createKey(def, pf, sessionInfo)))));
                }
            }
        }
        if (propertyItems.size() == 0 && subCategories.size() == 0) {
            throw new Exception("No property definitions or sub-categories for this category (" + parentCategory + ").");
        }
        pf.setParentCategory(parentCategory);
        pf.setSubCategories(subCategories);
        pf.setCategoryDefinitions(categoryDefinitions);
        Collections.sort(propertyItems);
        pf.setPropertyItems(propertyItems.toArray(new PropertyItem[propertyItems.size()]));
    }

    public abstract AbstractPropertyKey createKey(PropertyDefinition definition, AbstractPropertiesForm form, SessionInfo sessionInfo);
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer/src/com/sslexplorer/properties/actions/AbstractPropertiesAction.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.properties.actions;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.sslexplorer.boot.AbstractPropertyKey;
import com.sslexplorer.boot.PropertyClass;
import com.sslexplorer.boot.PropertyDefinition;
import com.sslexplorer.boot.PropertyDefinitionCategory;
import com.sslexplorer.boot.PropertyList;
import com.sslexplorer.boot.Util;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.actions.AuthenticatedDispatchAction;
import com.sslexplorer.properties.Property;
import com.sslexplorer.properties.PropertyItem;
import com.sslexplorer.properties.forms.AbstractPropertiesForm;
import com.sslexplorer.properties.forms.PropertiesForm;
import com.sslexplorer.security.LogonControllerFactory;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.security.User;

public abstract class AbstractPropertiesAction extends AuthenticatedDispatchAction {
    static Log log = LogFactory.getLog(AbstractPropertiesAction.class);

    public AbstractPropertiesAction() {
        super();
    }

    public ActionForward reset(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.clearValues();
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        return rebuildItems(mapping, f.getParentCategory(), f, request, user);
    }

    public ActionForward unspecified(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                     HttpServletResponse response) throws Exception {
        // Initialise form
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        pf.clearValues();
        pf.setUpdateAction(mapping.getPath() + ".do");
        pf.setInput(mapping.getInput());

        // Now try the struts supplied action mapping parameter
        if (mapping.getParameter() != null && !mapping.getParameter().equals("")) {
            PropertyList pl = new PropertyList(mapping.getParameter());
            Properties pr = pl.getAsNameValuePairs();
            BeanUtils.populate(pf, pr);
        }

        if ("changeSelectedCategory".equalsIgnoreCase(pf.getActionTarget())) {
            pf.setSelectedCategory(pf.getNewSelectedCategory());
        }

        // Build and display
        return rebuildItems(mapping, pf.getParentCategory(), pf, request, getSessionInfo(request).getUser());
    }

    public ActionForward changeSelectedCategory(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                                HttpServletResponse response) throws Exception {
        if (log.isDebugEnabled())
            log.debug("Storing properties");
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.storeItems();
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        f.setSelectedCategory(f.getNewSelectedCategory());
        f.setNewSelectedCategory(-1);
        return rebuildItems(mapping, f.getParentCategory(), f, request, user);
    }

    public ActionForward cancel(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        pf.setSelectedCategory(-1);
        pf.clearValues();
        int newCategory = pf.popCategory();
        pf.setParentCategory(newCategory);
        ActionForward fwd = rebuildItems(mapping, newCategory, pf, request, user);
        ActionForward cancel = mapping.findForward("cancel");
        return cancel != null ? cancel : fwd;
    }

    public ActionForward displayCategory(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                         HttpServletResponse response) throws Exception {
        AbstractPropertiesForm pf = (AbstractPropertiesForm) form;
        User user = isSetupMode() ? null : LogonControllerFactory.getInstance().getUser((HttpServletRequest) request);
        pf.setSelectedCategory(-1);
        pf.pushCategory(pf.getParentCategory());
        pf.setParentCategory(pf.getNewSelectedCategory());
        pf.setNewSelectedCategory(-1);
        return rebuildItems(mapping, pf.getParentCategory(), pf, request, user);
    }

    public ActionForward commit(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response)
                    throws Exception {
    	SessionInfo sessionInfo = getSessionInfo(request);
        boolean restartRequired = false;
    	
        // Temporarily store the properties
        if (log.isDebugEnabled())
            log.debug("Commiting properties");
        AbstractPropertiesForm f = (AbstractPropertiesForm) form;
        f.storeItems();

        // Check for save abilitiy
        if (!((PropertiesForm) form).getEnabled()) {
            throw new Exception("Disabled.");
        }

        // Set the properties
        for (Iterator i = f.storedItems(); i.hasNext();) {
            PropertyItem item = (PropertyItem) i.next();
            PropertyDefinition def = item.getDefinition();
            if(def.isRestartRequired()) {
                restartRequired = true;
            }
            String val = null;
            val = String.valueOf(item.getPropertyValue());
            if (log.isDebugEnabled())
                log.debug("Setting '" + def.getName() + "' to '" + val + "'");
            Property.setProperty(createKey(item.getDefinition(), f, sessionInfo), val, sessionInfo);
        }
        CoreUtil.resetMainNavigation(request.getSession());

        // Messages
        ActionMessages messages = new ActionMessages();
        messages.add(Globals.MESSAGES_KEY, new ActionMessage("message.propertiesSaved"));
        saveMessages(request, messages);

        // Clean up and forward
        f.clearValues();
        ActionForward fwd;
        if (f.getForwardTo() != null && !f.getForwardTo().equals("")) {
            fwd = new ActionForward(f.getForwardTo(), f.isRedirect());
        } else {
            fwd = cancel(mapping, form, request, response);
        }
        if(restartRequired) {
            String orig = fwd.getPath();
            fwd = mapping.findForward("restartRequired"); 
            fwd = CoreUtil.addParameterToForward(fwd, "no", orig);
        }
        return fwd;
    }

    protected String getMethodName(ActionMapping mapping, ActionForm form, HttpServletRequest request,
                                   HttpServletResponse response, String parameter) throws Exception {
        return request.getParameter("actionTarget");
    }

    protected ActionForward rebuildItems(ActionMapping mapping, int parentCategory, AbstractPropertiesForm pf, HttpServletRequest request, User user)
                    throws Exception {
    	SessionInfo sessionInfo = getSessionInfo(request);
        List<PropertyDefinitionCategory> categoryDefinitions = new ArrayList<PropertyDefinitionCategory>();
        List<PropertyDefinitionCategory> subCategories = new ArrayList<PropertyDefinitionCategory>();
        Collection<PropertyDefinitionCategory> sourceCategories = null;
        List<PropertyItem> propertyItems = new ArrayList<PropertyItem>();
        for (PropertyClass propertyClass : pf.getPropertyClasses()) {

            /*
             * If no parent category is supplied, then assume all categories in
             * the class, otherwise get all the child categories of the supplied
             * one
             */
            if (parentCategory == 0) {
                sourceCategories = propertyClass.getCategories();
            } else {
                PropertyDefinitionCategory category = propertyClass.getPropertyDefinitionCategory(parentCategory);
                if (category != null) {
                    sourceCategories = category.getCategories();
                }
                else {
                    sourceCategories = null;
                }
            }

            if (sourceCategories != null) {
                for (PropertyDefinitionCategory def : sourceCategories) {
                    if(def.isEnabled()) {
                        if (def.size() > 0) {
                        	if(!subCategories.contains(def)) {
                        		// Only add the subcategory if it has at least one enabled subcategory within it
                                for(PropertyDefinitionCategory subcat : def.getCategories()) {
                                	if(subcat.isEnabled()) {
                                		subCategories.add(def);
                                		break;
                                	}
                                }
                        	}
                        } else {
                        	if(!categoryDefinitions.contains(def)) {
                        		categoryDefinitions.add(def);
	                            if (pf.getSelectedCategory() == -1) {
	                                pf.setSelectedCategory(def.getId());
	                            }
                        	}
                        }
                    }
                }
            }

            for (PropertyDefinition def : propertyClass.getDefinitions()) {
                if (!def.isHidden() && def.getCategory() == pf.getSelectedCategory()) {
                    propertyItems.add(pf.retrieveItem(def.getName(), new PropertyItem(this, request, def, Property
                                    .getProperty(createKey(def, pf, sessionInfo)))));
                }
            }
        }
        pf.setParentCategory(parentCategory);
        pf.setSubCategories(subCategories);
        pf.setCategoryDefinitions(categoryDefinitions);
        Collections.sort(propertyItems);
        pf.setPropertyItems(propertyItems.toArray(new PropertyItem[propertyItems.size()]));

        if(propertyItems.size() != 0 || subCategories.size() != 0) {
            return mapping.findForward("display");
        }
        else {
        	log.warn("No categories or definitions to display. May be the result of a session timeout.");
            return mapping.findForward("home");
        }
    }

    public abstract AbstractPropertyKey createKey(PropertyDefinition definition, AbstractPropertiesForm form, SessionInfo sessionInfo);
}
